# QuantGYMM

This a simple package to deal with bond pricing and bond hedging. This project was born during the Group Assignment for the Fixed Income course in the MAFIRM at Collegio Carlo Alberto. It is a simple Python package that allows to fit term structures and perform bond pricing. Please see the [documentation](https://github.com/GianlucaBroll95/QuantGYMM/blob/master/docs/index.md) for further details.

## Getting started


Before installing 'QuantGYMM', be sure that you have a Python version >= 3.9 installed in you computer/local enviroment. If you are using a conda, I suggest to create a virtual enviroment and install a suitable Python version. 

### Suggested Set Up:

1) Create virtual enviroment and activate it:
```
conda create --name [your_env_name_here] python=3.10
conda activate [your_env_name_here]
```
2) Install Jypyter (optional):
```
conda install jupyter
```
3) Install QuantGYMM:
```
pip install QuantGYMM
```
or (better):
```
python3 -m pip install QuantGYMM
```
### Alternative:
1) You could clone the repository:
    
```
git clone https://github.com/GianlucaBroll95/QuantGYMM.git
```
and then install running from within the directory:
```
pip install .
```
